@@ -1,6 +1,6 @@
 
 /*
-   $Id: dbdimp.c,v 1.35 2001/04/09 17:44:18 mergl Exp $
+   $Id: dbdimp.c,v 1.36 2001/04/20 21:01:17 mergl Exp $
 
    Copyright (c) 1997,1998,1999,2000 Edmund Mergl
    Portions Copyright (c) 1994,1995,1996,1997 Tim Bunce
@@ -1104,8 +1104,8 @@ dbd_st_execute (sth, imp_sth)   /* <= -2:error, >=0:ok row count, (-1=unknown co
                     if (*val == '\'') {
                         *dest++ = '\'';
                     }
-	            /* escape backslash except for octal presentation */
-                    if (*val == '\\' && !(isdigit(*(val+1)) && isdigit(*(val+2)) && isdigit(*(val+3))) ) {
+	            /* escape backslash */
+                    if (*val == '\\') {
                         *dest++ = '\\';
                     }
                 }
